=========
Resources
=========

 - `NASA GSFC ICESat-2 mission site <https://icesat-2.gsfc.nasa.gov/>`_
 - `NASA ICESat-2 Science Computing Facility <https://icesat-2-scf.gsfc.nasa.gov/>`_
 - `NASA GSFC ICESat-2 Data Product Documentation <https://icesat-2.gsfc.nasa.gov/science/data-products>`_
 - `NSIDC: ICESat-2 Datasets <https://nsidc.org/data/icesat-2/data-sets>`_

Software
########

 - `SlideRule <https://github.com/ICESat2-SlideRule/sliderule-python>`_: Python client for SlideRule with a YAPC implementation for photon events
 - `read-ICESat-2 <https://github.com/tsutterley/read-ICESat-2>`_: Python tools for obtaining and working with elevation data from the NASA ICESat-2 mission
 - `ICESat-2HackWeek <https://github.com/ICESAT-2HackWeek>`_: University of Washington ICESat-2 Hack Week Repositories with tutorials about YAPC and SlideRule
